==> tatooine-gtx-0.1.0-src.tar.bz2: tatooine-gtx-0.1.0/src/test/java/jp/sf/tatooine/gtx/filter/MidTest.java <==
/* 
 * Copyright 2007 Tatooine Project <http://tatooine.sourceforge.jp/> 
 *  
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 *     http://www.apache.org/licenses/LICENSE-2.0
 *  
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.sf.tatooine.gtx.filter;

import static org.junit.Assert.*;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * MidTest.
 *
 * @author  Tooru Noda
 * @version 1.0 2007/04/18
 * @since   JDK5.0 Tiger
 */
public class MidTest {

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testInvokeN1() {
		Mid target = new Mid();
		String[] args = {"3", "5"};
		String result = target.invoke("1234567890", args);
		assertEquals("45678", result);
	}

	@Test
	public void testInvokeE1() {
		Mid target = new Mid();
		String[] args = {};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}

	@Test
	public void testInvokeE2() {
		Mid target = new Mid();
		String[] args = {"a", "5"};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}

	@Test
	public void testInvokeE3() {
		Mid target = new Mid();
		String[] args = {"3", "b"};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}

	@Test
	public void testInvokeE4() {
		Mid target = new Mid();
		String[] args = {"-3", "5"};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}

	@Test
	public void testInvokeE5() {
		Mid target = new Mid();
		String[] args = {"3", "-5"};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) {
			e.printStackTrace();
		}
	}
	
}

==> tatooine-gtx-0.2.0-src.tar.bz2: tatooine-gtx-0.2.0/src/test/java/jp/sf/tatooine/gtx/filter/MidTest.java <==
/* 
 * Copyright 2007 Tatooine Project <http://tatooine.sourceforge.jp/> 
 *  
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 *     http://www.apache.org/licenses/LICENSE-2.0
 *  
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.sf.tatooine.gtx.filter;

import static org.junit.Assert.*;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * MidTest.
 *
 * @author  Tooru Noda
 * @version 1.0 2007/04/18
 * @since   JDK5.0 Tiger
 */
public class MidTest {

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testInvokeN1() {
		Mid target = new Mid();
		String[] args = {"3", "5"};
		String result = target.invoke("1234567890", args);
		assertEquals("45678", result);
	}

	@Test
	public void testInvokeE1() {
		Mid target = new Mid();
		String[] args = {};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) { }
	}

	@Test
	public void testInvokeE2() {
		Mid target = new Mid();
		String[] args = {"a", "5"};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) { }
	}

	@Test
	public void testInvokeE3() {
		Mid target = new Mid();
		String[] args = {"3", "b"};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) { }
	}

	@Test
	public void testInvokeE4() {
		Mid target = new Mid();
		String[] args = {"-3", "5"};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) { }
	}

	@Test
	public void testInvokeE5() {
		Mid target = new Mid();
		String[] args = {"3", "-5"};
		try {
			String result = target.invoke("1234567890", args);
			fail(result);
		}
		catch (Exception e) { }
	}
	
}
